summaryrefslogtreecommitdiffstats
path: root/quanta/src/quantaview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
commite985f7e545f4739493965aad69bbecb136dc9346 (patch)
tree54afd409d8acd6202dd8ab611d24e78c28e4c0a0 /quanta/src/quantaview.h
parentf7670c198945adc3b95ad69a959fe5f8ae55b493 (diff)
downloadtdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.tar.gz
tdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.zip
TQt4 port kdewebdev
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1237029 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'quanta/src/quantaview.h')
-rw-r--r--quanta/src/quantaview.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/quanta/src/quantaview.h b/quanta/src/quantaview.h
index e3688d93..dc6d7414 100644
--- a/quanta/src/quantaview.h
+++ b/quanta/src/quantaview.h
@@ -18,7 +18,7 @@
#ifndef QUANTAVIEW_H
#define QUANTAVIEW_H
-// include files for Qt
+// include files for TQt
#include <tqguardedptr.h>
#include <tqwidget.h>
#include <tqptrlist.h>
@@ -64,10 +64,11 @@ class Node;
class QuantaView : public KMdiChildView
{
Q_OBJECT
+ TQ_OBJECT
public:
- QuantaView(TQWidget *parent = 0, const char *name=0, const TQString &caption = TQString::null);
+ QuantaView(TQWidget *tqparent = 0, const char *name=0, const TQString &caption = TQString());
~QuantaView();
/** returns true if the view can be removed, false otherwise */
@@ -104,7 +105,7 @@ public:
void reloadVPLView(bool force = false);
/** reload the Quanta view from the Node Tree. Set force to true if you want to reload even if not necessary. */
void reloadSourceView(bool force = false);
/** Return the curren views layout*/
int currentViewsLayout() {return m_currentViewsLayout;}
void reloadLayout();
@@ -129,12 +130,12 @@ public:
void insertTag( const char *tag);
/** Insert a new tag by bringing up the TagDialog. */
- void insertNewTag(const TQString &tag, const TQString &attr = TQString::null, bool insertInLine = true);
+ void insertNewTag(const TQString &tag, const TQString &attr = TQString(), bool insertInLine = true);
/**
* This function take the output of the TagAction, parse it into Nodes and insert it
* in the Node tree. Then kafka will take care of updating itself from the Node Tree.
*/
- void insertOutputInTheNodeTree(const TQString &str1, const TQString &str2 = TQString::null, Node *node = 0L);
+ void insertOutputInTheNodeTree(const TQString &str1, const TQString &str2 = TQString(), Node *node = 0L);
enum ViewFocus {
SourceFocus = 0,
@@ -220,7 +221,7 @@ private:
TQGuardedPtr<KafkaDocument> m_kafkaDocument;
TQSplitter *m_splitter;
TQGridLayout *m_viewLayout;
- int m_currentViewsLayout; ///< holds the current layout, which can be SourceOnly, VPLOnly or SourceAndVPL
+ int m_currentViewsLayout; ///< holds the current tqlayout, which can be SourceOnly, VPLOnly or SourceAndVPL
int m_currentFocus;
bool m_saveResult;
bool m_eventLoopStarted;
@@ -104,7 +105,7 @@ public:
/** reload the Quanta view from the Node Tree. Set force to true if you want to reload even if not necessary. */
void reloadSourceView(bool force = false);
- /** Return the curren views layout*/
+ /** Return the curren views tqlayout*/
int currentViewsLayout() {return m_currentViewsLayout;}
void reloadLayout();